@@ -21,7 +21,7 @@ Generator <- R7Class(
     },
     set_current_seed = function(seed) {
       if ((!is.integer(seed)) && (!inherits(seed, "integer64"))) {
-        stop("Seed must an integer or integer64.")
+        type_error("Seed must be integer or integer64.")
       }
 
       seed <- as.character(seed)
@@ -148,7 +148,7 @@ cuda_set_rng_state <- function(state, device = NULL) {
   }
   
   if (length(state) != cuda_device_count()) {
-    cli::cli_abort("Expected length {.var state} ({.val {length(state)}}) equal to the number of cuda devices ({.val {cuda_device_count()}}).")
+    cli_abort("Expected length {.var state} ({.val {length(state)}}) equal to the number of cuda devices ({.val {cuda_device_count()}}).")
   }
   
   for (i in seq_along(state)) {
