@@ -1,45 +1,35 @@
 Scalar <- R7Class(
-  classname = "torch_scalar", 
-  
+  classname = "torch_scalar",
   public = list(
-    
     ptr = NULL,
-    
     initialize = function(x, ptr = NULL) {
-      
       if (!is.null(ptr)) {
         return(ptr)
       }
-      
-      cpp_torch_scalar(x);
+
+      cpp_torch_scalar(x)
     },
-    
     to_r = function() {
-      
       type <- self$type
-      
-      if (type == torch_double())
+
+      if (type == torch_double()) {
         f <- cpp_torch_scalar_to_double
-      else if (type == torch_float())
+      } else if (type == torch_float()) {
         f <- cpp_torch_scalar_to_float
-      else if (type == torch_bool())
+      } else if (type == torch_bool()) {
         f <- cpp_torch_scalar_to_bool
-      else if (type == torch_int())
+      } else if (type == torch_int()) {
         f <- cpp_torch_scalar_to_int
-      else if (type == torch_long())
+      } else if (type == torch_long()) {
         f <- cpp_torch_scalar_to_int
-      
+      }
+
       f(self$ptr)
     },
-    
     print = function() {
       cat("torch_scalar\n")
     }
-    
   ),
-  
-  
-  
   active = list(
     type = function() {
       torch_dtype$new(ptr = cpp_torch_scalar_dtype(self$ptr))
@@ -48,7 +38,6 @@ Scalar <- R7Class(
       self
     }
   )
-  
 )
 
 torch_scalar <- function(x) {
@@ -58,4 +47,3 @@ torch_scalar <- function(x) {
 is_torch_scalar <- function(x) {
   inherits(x, "torch_scalar")
 }
-
