@@ -1,5 +1,4 @@
-#include "torch_types.h"
-#include "utils.h"
+#include <torch.h>
 
 // [[Rcpp::export]]
 std::string cpp_memory_format_to_string(Rcpp::XPtr<XPtrTorchMemoryFormat> x) {
@@ -7,16 +6,16 @@ std::string cpp_memory_format_to_string(Rcpp::XPtr<XPtrTorchMemoryFormat> x) {
 }
 
 // [[Rcpp::export]]
-XPtrTorchMemoryFormat cpp_torch_contiguous_format () {
+XPtrTorchMemoryFormat cpp_torch_contiguous_format() {
   return XPtrTorchMemoryFormat(lantern_MemoryFormat_Contiguous());
 }
 
 // [[Rcpp::export]]
-XPtrTorchMemoryFormat cpp_torch_preserve_format () {
+XPtrTorchMemoryFormat cpp_torch_preserve_format() {
   return XPtrTorchMemoryFormat(lantern_MemoryFormat_Preserve());
 }
 
 // [[Rcpp::export]]
-XPtrTorchMemoryFormat cpp_torch_channels_last_format () {
+XPtrTorchMemoryFormat cpp_torch_channels_last_format() {
   return XPtrTorchMemoryFormat(lantern_MemoryFormat_ChannelsLast());
 }
