@@ -3,7 +3,7 @@ cd torch
 export TORCH_TEST=1
 export TORCH_INSTALL=1
 
-Rscript -e "install.packages(c('remotes', 'rcmdcheck'))"
+Rscript -e "install.packages(c('remotes', 'rcmdcheck', 'markdown'))"
 Rscript -e "remotes::install_deps(dependencies = TRUE)"
 
 if "$BUILD_LANTERN" = "true"; then
